.. module:: numpy.matlib

Matrix library (:mod:`numpy.matlib`)
************************************

.. currentmodule:: numpy

This module contains all functions in the :mod:`numpy` namespace, with
the following replacement functions that return :class:`matrices
<matrix>` instead of :class:`ndarrays <ndarray>`.

.. currentmodule:: numpy

Functions that are also in the numpy namespace and return matrices

.. autosummary::

   mat
   matrix
   asmatrix
   bmat


Replacement functions in `matlib`

.. currentmodule:: numpy.matlib

.. autosummary::
   :toctree: generated/

   empty
   zeros
   ones
   eye
   identity
   repmat
   rand
   randn
